Method: Fluent::Evaluators#wait_until
- Defined in:
- lib/fluent/evaluators.rb
#wait_until(timeout = Fluent.page_level_wait, message = nil, &block) ⇒ Object Also known as: wait_for
Provides a context for an action that must succeed within a given time period. The logic here is simply that the result of the action will be true (meaning the action was carried out) or false, which means the action did not succeed in the time allotted.
90 91 92 |
# File 'lib/fluent/evaluators.rb', line 90 def wait_until(timeout=Fluent.page_level_wait, =nil, &block) platform.wait_until(timeout, , &block) end |